@@ -4,23 +4,7 @@ use Mojo::Base -base;
 use Role::Tiny;
 use Carp qw/croak/;
 
-our $VERSION = '1.001003'; # VERSION
-
-# TODO: replace with Mojo::DOM's native ->val, once that's released
-sub __val {
-  my $dom = shift;
-
-  # "option"
-  my $tag = $dom->tag;
-  return $dom->{value} // $dom->text if $tag eq 'option';
-
-  # "select"
-  return $dom->find('option[selected]')->map(sub{__val($_)})->to_array
-    if $tag eq 'select';
-
-  # "textarea", "input" or "button"
-  return $tag eq 'textarea' ? $dom->text : $dom->{value};
-}
+our $VERSION = '1.001004'; # VERSION
 
 sub click_ok {
     my ( $self, $selector, $extra_params ) = @_;
@@ -44,7 +28,7 @@ sub click_ok {
         next unless ref $extra_params->{$_} eq 'CODE';
         ( my $name = $_ ) =~ s/"/\\"/g;
         $extra_params->{$_} = $extra_params->{$_}->(
-            __val( $el->at(qq{[name="$name"]}) )
+            $el->at(qq{[name="$name"]})->val
         );
     }
 
@@ -77,7 +61,7 @@ sub click_ok {
 sub _get_controls {
     my ( $self, $el ) = @_;
 
-    map +( $_->attr('name') => __val($_) ),
+    map +( $_->attr('name') => $_->val ),
         $el->find(
             'input:not([type=button]):not([type=submit]):not([type=image])'
             . ':not([type=checkbox]):not([type=radio]),'
@@ -98,7 +82,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Znet Zoffix app  Subrefs subrefs ENV
+=for stopwords Znet Zoffix app  Subrefs subrefs ENV VARS
 
 =head1 NAME
 
